Clipboard

Struct Clipboard 

pub struct Clipboard { /* private fields */ }
The builtin, internal clipboard of the editor.

This is useful particularly when the terminal doesn’t support OSC 52 or when the clipboard contents are huge (e.g. 1GiB).

Implementations

Source

impl Clipboard

pub fn wants_host_sync(&self) -> bool

If true, we should emit a OSC 52 sequence to sync the clipboard with the hosting terminal.

pub fn mark_as_synchronized(&mut self)

Call this once the clipboard has been synchronized with the host.

pub fn is_line_copy(&self) -> bool

The editor has a special behavior when you have no selection and press Ctrl+C: It copies the current line to the clipboard. Then, when you paste it, it inserts the line at the start of the current line. This effectively prepends the current line with the copied line. clipboard_line_start is true in that case.

pub fn read(&self) -> &[u8]

Returns the current contents of the clipboard.

pub fn write(&mut self, data: Vec<u8>)

Fill the clipboard with the given data.

pub fn write_was_line_copy(&mut self, line_copy: bool)