Module fuzzy

Module fuzzy 

Fuzzy search algorithm based on the one used in VS Code (/src/vs/base/common/fuzzyScorer.ts). Other algorithms exist, such as Sublime Text’s, or the one used in fzf, but I figured that this one is what lots of people may be familiar with.

Functions

score_fuzzy