Rect

Struct Rect 

pub struct Rect {
    pub left: CoordType,
    pub top: CoordType,
    pub right: CoordType,
    pub bottom: CoordType,
}
A 2D rectangle. Uses CoordType.

Fields

left: CoordTypetop: CoordTyperight: CoordTypebottom: CoordType

Implementations

Source

impl Rect

pub fn one(value: CoordType) -> Self

Mimics CSS’s padding property where padding: a is a a a a.

pub fn two(top_bottom: CoordType, left_right: CoordType) -> Self

Mimics CSS’s padding property where padding: a b is a b a b, and a is top/bottom and b is left/right.

pub fn three(top: CoordType, left_right: CoordType, bottom: CoordType) -> Self

Mimics CSS’s padding property where padding: a b c is a b c b, and a is top, b is left/right, and c is bottom.

pub fn is_empty(&self) -> bool

Is the rectangle empty?

pub fn width(&self) -> CoordType

Width of the rectangle.

pub fn height(&self) -> CoordType

Height of the rectangle.

pub fn contains(&self, point: Point) -> bool

Check if it contains a point.

pub fn intersect(&self, rhs: Self) -> Self

Intersect two rectangles.