AsciiStringHelpers

Trait AsciiStringHelpers 

pub trait AsciiStringHelpers {
    // Required method
    fn starts_with_ignore_ascii_case(&self, prefix: &str) -> bool;
}
Helpers for ASCII string comparisons.

Required Methods

fn starts_with_ignore_ascii_case(&self, prefix: &str) -> bool

Tests if a string starts with a given ASCII prefix.

This function name really is a mouthful, but it’s a combination of str::starts_with and str::eq_ignore_ascii_case.

Implementations on Foreign Types

Source

impl AsciiStringHelpers for str

Implementors