fold_case

Function fold_case 

pub fn fold_case<'a>(arena: &'a Arena, input: &str) -> ArenaString<'a>
Converts the given UTF-8 string to lower case.

Case folding differs from lower case in that the output is primarily useful to machines for comparisons. It’s like applying Unicode normalization.