Module input

Module input 

Parses VT sequences into input events.

In the future this allows us to take apart the application and support input schemes that aren’t VT, such as UEFI, or GUI.

Modules

kbmod
Keyboard modifiers.
vk
Keyboard keys.

Structs

InputKey
Represents a key/modifier combination.
InputKeyMod
A keyboard modifier. Ctrl/Alt/Shift.
InputMouse
Mouse input.
Parser
Parses VT sequences into input events.
Stream
An iterator that parses VT sequences into input events.

Enums

Input
Primary result type of the parser.
InputMouseState
Mouse input state. Up/Down, Left/Right, etc.