Module lines_bwd

Module lines_bwd 

Functions

lines_bwd
Starting from the offset in haystack with a current line index of line, this seeks backwards to the line_stop-nth line and returns the new offset and the line index at that point.