Module lines_fwd

Module lines_fwd 

Functions

lines_fwd
Starting from the offset in haystack with a current line index of line, this seeks to the line_stop-nth line and returns the new offset and the line index at that point.