virtual_commit

Function virtual_commit 

pub unsafe fn virtual_commit(base: NonNull<u8>, size: usize) -> Result<()>
Commits a virtual memory region of the given size.

Safety

This function is unsafe because it uses raw pointers. Make sure to only pass pointers acquired from virtual_reserve and to pass a size less than or equal to the size passed to virtual_reserve.