pub enum Anchor {
Last,
Parent,
Root,
}Expand description
Controls to which node the floater is anchored.
Variants
Last
The floater is attached relative to the node created last.
Parent
The floater is attached relative to the current node (= parent of new nodes).
Root
The floater is attached relative to the root node (= usually the viewport).