ListSelection

Enum ListSelection 

pub enum ListSelection {
    Unchanged,
    Selected,
    Activated,
}
Informs you about the change that was made to the list selection.

Variants



Unchanged

The selection wasn’t changed.



Selected

The selection was changed to the current list item.



Activated

The selection was changed to the current list item and the item was also activated (Enter or Double-click).