Overflow

Enum Overflow 

pub enum Overflow {
    Clip,
    TruncateHead,
    TruncateMiddle,
    TruncateTail,
}
Controls the text overflow behavior of a label when the text doesn’t fit the container.

Variants



Clip

Text is simply cut off when it doesn’t fit.



TruncateHead

An ellipsis is shown at the end of the text.



TruncateMiddle

An ellipsis is shown in the middle of the text.



TruncateTail

An ellipsis is shown at the beginning of the text.