pub enum Position {
Stretch,
Left,
Center,
Right,
}Expand description
Controls the position of a node relative to its parent.
Variants
Stretch
The child is stretched to fill the parent.
Left
The child is positioned at the left edge of the parent.
Center
The child is positioned at the center of the parent.
Right
The child is positioned at the right edge of the parent.