skip_newline

Function skip_newline 

pub fn skip_newline(text: &[u8], offset: usize) -> usize
Returns an offset past a newline.

If offset is right in front of a newline, this will return the offset past said newline.