MeasurementConfig

Struct MeasurementConfig 

pub struct MeasurementConfig<'doc> { /* private fields */ }
Your entrypoint to navigating inside a ReadableDocument.

Implementations

Source

impl<'doc> MeasurementConfig<'doc>

pub fn new(buffer: &'doc dyn ReadableDocument) -> Self

Creates a new MeasurementConfig for the given document.

pub fn with_cursor(self, cursor: Cursor) -> Self

Sets the initial cursor to the given position.

WARNING: While the code doesn’t panic if the cursor is invalid, the results will obviously be complete garbage.

pub fn with_tab_size(self, tab_size: CoordType) -> Self

Sets the tab size.

Defaults to 8, because that’s what a tab in terminals evaluates to.

pub fn with_word_wrap_column(self, word_wrap_column: CoordType) -> Self

You want word wrap? Set it here!

Defaults to 0, which means no word wrap.

pub fn goto_offset(&mut self, offset: usize) -> Cursor

Navigates forward to the given absolute offset.

Returns

The cursor position after the navigation.

pub fn goto_logical(&mut self, logical_target: Point) -> Cursor

Navigates forward to the given logical position.

Logical positions are in lines and grapheme clusters.

Returns

The cursor position after the navigation.

pub fn goto_visual(&mut self, visual_target: Point) -> Cursor

Navigates forward to the given visual position.

Visual positions are in laid out rows and columns.

Returns

The cursor position after the navigation.

pub fn cursor(&self) -> Cursor

Returns the current cursor position.