Token

Enum Token 

pub enum Token<'parser, 'input> {
    Text(&'input str),
    Ctrl(char),
    Esc(char),
    SS3(char),
    Csi(&'parser Csi),
    Osc {
        data: &'input str,
        partial: bool,
    },
    Dcs {
        data: &'input str,
        partial: bool,
    },
}
The parser produces these tokens.

Variants



Text(&'input str)

A bunch of text. Doesn’t contain any control characters.



Ctrl(char)

A single control character, like backspace or return.



Esc(char)

We encountered ESC x and this contains x.



SS3(char)

We encountered ESC O x and this contains x.



Csi(&'parser Csi)

A CSI sequence started with ESC [.

They are the most common escape sequences. See Csi.



Osc

An OSC sequence started with ESC ].

The sequence may be split up into multiple tokens if the input is given in chunks. This is indicated by the partial field.

Fields

data: &'input str
partial: bool


Dcs

An DCS sequence started with ESC P.

The sequence may be split up into multiple tokens if the input is given in chunks. This is indicated by the partial field.

Fields

data: &'input str
partial: bool