pub struct Parser { /* private fields */ }Implementations
Sourceimpl Parser
impl Parser
pub fn new() -> Self
Sourcepub fn read_timeout(&mut self) -> Duration
pub fn read_timeout(&mut self) -> Duration
Suggests a timeout for the next call to read().
We need this because of the ambiguity of whether a trailing escape character in an input is starting another escape sequence or is just the result of the user literally pressing the Escape key.