active_zoom_at

Function active_zoom_at 

pub fn active_zoom_at(project: &EditProject, frame: Frame) -> ZoomTransform
The active zoom transform at project frame across the whole project: the transform of the first zoom region whose window contains frame, or ZoomTransform::identity when none do. The ramp is derived from the project’s frame rate.