pub trait AsciiStringHelpers {
// Required method
fn starts_with_ignore_ascii_case(&self, prefix: &str) -> bool;
}Expand description
Helpers for ASCII string comparisons.
Required Methods
Sourcefn starts_with_ignore_ascii_case(&self, prefix: &str) -> bool
fn starts_with_ignore_ascii_case(&self, prefix: &str) -> bool
Tests if a string starts with a given ASCII prefix.
This function name really is a mouthful, but it’s a combination
of str::starts_with and str::eq_ignore_ascii_case.