Parses VT sequences into input events.
In the future this allows us to take apart the application and support input schemes that aren’t VT, such as UEFI, or GUI.
Modules
Structs
- Input
Key - Represents a key/modifier combination.
- Input
KeyMod - A keyboard modifier. Ctrl/Alt/Shift.
- Input
Mouse - Mouse input.
- Parser
- Parses VT sequences into input events.
- Stream
- An iterator that parses VT sequences into input events.
Enums
- Input
- Primary result type of the parser.
- Input
Mouse State - Mouse input state. Up/Down, Left/Right, etc.