Module sys

Module sys 

Platform abstractions.

Structs

Deinit

Enums

FileId
A unique identifier for a file.

Functions

apperr_format
Formats a platform error code into a human-readable string.
apperr_is_not_found
Checks if the given error is a “file not found” error.
canonicalize
Canonicalizes the given path.
drives
file_id
Returns a unique identifier for the given file by handle or path.
get_proc_address
Loads a function from a dynamic library.
init
Initializes the platform-specific state.
inject_window_size_into_stdin
During startup we need to get the window size from the terminal. Because I didn’t want to type a bunch of code, this function tells read_stdin to inject a fake sequence, which gets picked up by the input parser and provided to the TUI code.
load_libicui18n
Loads the internationalization portion of ICU4C.
load_libicuuc
Loads the “common” portion of ICU4C.
open_stdin_if_redirected
Check if the stdin handle is redirected to a file, etc.
preferred_languages
Returns a list of preferred languages for the current user.
read_stdin
Reads from stdin.
switch_modes
Switches the terminal into raw mode, etc.
virtual_commit
Commits a virtual memory region of the given size.
virtual_release
Releases a virtual memory region of the given size.
virtual_reserve
Reserves a virtual memory region of the given size. To commit the memory, use virtual_commit. To release the memory, use virtual_release.
write_stdout
Writes a string to stdout.