Platform abstractions.
Structs
Enums
- FileId
- A unique identifier for a file.
Functions
- apperr_
format - Formats a platform error code into a human-readable string.
- apperr_
is_ not_ found - Checks if the given error is a “file not found” error.
- canonicalize
- Canonicalizes the given path.
- drives
- file_id
- Returns a unique identifier for the given file by handle or path.
- get_
proc_ ⚠address - Loads a function from a dynamic library.
- init
- Initializes the platform-specific state.
- inject_
window_ size_ into_ stdin - During startup we need to get the window size from the terminal.
Because I didn’t want to type a bunch of code, this function tells
read_stdinto inject a fake sequence, which gets picked up by the input parser and provided to the TUI code. - load_
libicui18n - Loads the internationalization portion of ICU4C.
- load_
libicuuc - Loads the “common” portion of ICU4C.
- open_
stdin_ if_ redirected - Check if the stdin handle is redirected to a file, etc.
- preferred_
languages - Returns a list of preferred languages for the current user.
- read_
stdin - Reads from stdin.
- switch_
modes - Switches the terminal into raw mode, etc.
- virtual_
commit ⚠ - Commits a virtual memory region of the given size.
- virtual_
release ⚠ - Releases a virtual memory region of the given size.
- virtual_
reserve ⚠ - Reserves a virtual memory region of the given size.
To commit the memory, use
virtual_commit. To release the memory, usevirtual_release. - write_
stdout - Writes a string to stdout.