Platform abstractions.
Structs
Functions
- add_
icu_ proc_ suffix - apperr_
format - apperr_
is_ not_ found - canonicalize
- Returns the canonical, absolute form of a path with all intermediate components normalized and symbolic links resolved.
- file_id
- Returns a unique identifier for the given file by handle or path.
- get_
proc_ ⚠address - Loads a function from a dynamic library.
- icu_
proc_ suffix - ICU, by default, adds the major version as a suffix to each exported symbol.
They also recommend to disable this for system-level installations (
runConfigureICU Linux --disable-renaming), but I found that many (most?) Linux distributions don’t do this for some reason. This function returns the suffix, if any. - init
- inject_
window_ size_ into_ stdin - load_
libicui18n - load_
libicuuc - open_
stdin_ if_ redirected - preferred_
languages - read_
stdin - Reads from stdin.
- switch_
modes - virtual_
commit ⚠ - Commits a virtual memory region of the given size.
- virtual_
release ⚠ - Releases a virtual memory region of the given size.
- virtual_
reserve ⚠ - Reserves a virtual memory region of the given size.
To commit the memory, use
virtual_commit. To release the memory, usevirtual_release. - write_
stdout