pub unsafe fn get_proc_address<T>(
handle: NonNull<c_void>,
name: &CStr,
) -> Result<T>Expand description
Loads a function from a dynamic library.
Safety
This function is highly unsafe as it requires you to know the exact type of the function you’re loading. No type checks whatsoever are performed.