pub struct Csi {
pub params: [u16; 32],
pub param_count: usize,
pub private_byte: char,
pub final_byte: char,
}Expand description
A single CSI sequence, parsed for your convenience.
Fields
params: [u16; 32]The parameters of the CSI sequence.
param_count: usizeThe number of parameters stored in Csi::params.
private_byte: charThe private byte, if any. 0 if none.
The private byte is the first character right after the
ESC [ sequence. It is usually a ? or <.
final_byte: charThe final byte of the CSI sequence.
This is the last character of the sequence, e.g. m or H.