pub fn active_zoom_at(project: &EditProject, frame: Frame) -> ZoomTransformExpand description
The active zoom transform at project frame across the whole project:
the transform of the first zoom region whose window contains frame,
or ZoomTransform::identity when none do. The ramp is derived from
the project’s frame rate.